DesktopEnvironment

Enum DesktopEnvironment 

#[non_exhaustive]
pub enum DesktopEnvironment {
Show 21 variants Unknown(String), WebBrowser(String), Gnome, Windows, Lxde, Openbox, Mate, Xfce, Plasma, Cinnamon, I3, Aqua, Ios, Android, Console, Ubuntu, Ermine, Orbital, Niri, Hyprland, Cosmic,
}
The desktop environment of a system

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Unknown(String)

Unknown desktop environment



WebBrowser(String)

Running as Web Assembly on a web page



Gnome

Popular GTK-based desktop environment on Linux



Windows

One of the desktop environments for a specific version of Windows



Lxde

Linux desktop environment optimized for low resource requirements



Openbox

Stacking window manager for X Windows on Linux



Mate

Desktop environment for Linux, BSD and illumos



Xfce

Lightweight desktop enivornment for unix-like operating systems



Plasma

KDE Plasma desktop enviroment



Cinnamon

Default desktop environment on Linux Mint



I3

Tiling window manager for Linux



Aqua

Desktop environment for MacOS



Ios

Desktop environment for iOS



Android

Desktop environment for Android



Console

A desktop environment for a video game console



Ubuntu

Ubuntu-branded GNOME



Ermine

Default shell for Fuchsia



Orbital

Default desktop environment for Redox



Niri

Wayland scrolling window manager for Linux



Hyprland

Wayland tiling window manager for Linux



Cosmic

Rust based desktop environment on Linux

Implementations

Source

impl DesktopEnvironment

pub const fn is_gtk(&self) -> bool

Returns true if the desktop environment is based on GTK.

pub const fn is_kde(&self) -> bool

Returns true if the desktop environment is based on KDE.