pub fn desktop_env() -> Option<DesktopEnvironment>Expand description
Get the desktop environment (if any).
Example: “gnome” or “windows”
Returns None if a desktop environment is not available (for example in a
TTY or over SSH)
pub fn desktop_env() -> Option<DesktopEnvironment>Get the desktop environment (if any).
Example: “gnome” or “windows”
Returns None if a desktop environment is not available (for example in a
TTY or over SSH)