Language

Struct Language 

pub struct Language { /* private fields */ }
A spoken language identifier

Returned from various methods on LanguagePreferences

Use ToString::to_string() to convert to string of two letter lowercase language code followed an forward slash and uppercase country code (example: en/US).

The Default implementation can be used for fallbacks, and is set to en/US since it’s a common choice for lingua franca. It is not guaranteed to stay the same across whoami versions.

Language codes are defined in an unspecified superset of ISO 639, Country codes are defined in an unspecified superset of ISO 3166.

You can compare languages with strings (where the separator can be any of -, _, or /).